macro_rules! impl_int_conversion {
($P:ty, $I:ty) => { ... };
}Expand description
Simple macro for implementing conversion functions between unaligned integers and standard integers.
The standard integer types can cause alignment issues when placed in a
bytemuck::Pod, so these replacements are usable in all bytemuck Pod
types.