Module primitives

Module primitives 

Primitive types that can be used in Pods.

These are re-exported from solana_zero_copy::unaligned.

Structs

PodBool
The standard bool is not naturally zero-copy, define an unaligned replacement.
PodI16
Unaligned i16 type that can be embedded in bytemuck Pod types.
PodI64
Unaligned i64 type that can be embedded in bytemuck Pod types.
PodU16
Unaligned u16 type that can be embedded in bytemuck Pod types.
PodU32
Unaligned u32 type that can be embedded in bytemuck Pod types.
PodU64
Unaligned u64 type that can be embedded in bytemuck Pod types.
PodU128
Unaligned u128 type that can be embedded in bytemuck Pod types.