pub struct PodSlice<'data, T: Pod> { /* private fields */ }👎Deprecated since 0.6.0:
This struct will be removed in the next major release (1.0.0). Please use ListView instead.
Special type for using a slice of Pods in a zero-copy way
Implementations